@@ -41,24 +41,25 @@
 #define HCX_FILTER_ESSID		21
 #define HCX_FILTER_ESSID_PART		22
 #define HCX_FILTER_ESSID_PARTX		23
-#define HCX_FILTER_RC			24
-#define HCX_FILTER_RC_NOT		25
-#define HCX_FILTER_M12			26
-#define HCX_FILTER_M1234		27
-#define HCX_FILTER_M1M2ROGUE		28
-#define HCX_PSK				29
-#define HCX_PMK				30
-#define HCX_VENDOR_OUT			31
-#define HCX_INFO_OUT			32
-#define HCX_INFO_VENDOR_OUT		33
-#define HCX_INFO_VENDOR_AP_OUT		34
-#define HCX_INFO_VENDOR_CLIENT_OUT	35
-#define HCX_HCCAPX_IN			36
-#define HCX_HCCAPX_OUT			37
-#define HCX_HCCAP_IN			38
-#define HCX_HCCAP_OUT			39
-#define HCX_HCCAP_SINGLE_OUT		40
-#define HCX_JOHN_OUT			41
+#define HCX_FILTER_ESSID_REGEX		24
+#define HCX_FILTER_RC			25
+#define HCX_FILTER_RC_NOT		26
+#define HCX_FILTER_M12			27
+#define HCX_FILTER_M1234		28
+#define HCX_FILTER_M1M2ROGUE		29
+#define HCX_PSK				30
+#define HCX_PMK				31
+#define HCX_VENDOR_OUT			32
+#define HCX_INFO_OUT			33
+#define HCX_INFO_VENDOR_OUT		34
+#define HCX_INFO_VENDOR_AP_OUT		35
+#define HCX_INFO_VENDOR_CLIENT_OUT	36
+#define HCX_HCCAPX_IN			37
+#define HCX_HCCAPX_OUT			38
+#define HCX_HCCAP_IN			39
+#define HCX_HCCAP_OUT			40
+#define HCX_HCCAP_SINGLE_OUT		41
+#define HCX_JOHN_OUT			42
 #define HCX_PMKIDEAPOL_IN		'i'
 #define HCX_PMKIDEAPOL_OUT		'o'
 #define HCX_ESSID_OUT			'E'
@@ -92,9 +93,11 @@ static int sort_hashlist_by_essid(const void *a, const void *b)
 {
 const hashlist_t *ia = (const hashlist_t *)a;
 const hashlist_t *ib = (const hashlist_t *)b;
+int cmp;
 
-if(memcmp(ia->essid, ib->essid, ESSID_LEN_MAX) > 0) return 1;
-else if(memcmp(ia->essid, ib->essid, ESSID_LEN_MAX) < 0) return -1;
+cmp = memcmp(ia->essid, ib->essid, ESSID_LEN_MAX);
+if(cmp > 0) return 1;
+else if(cmp < 0) return -1;
 return 0;
 }
 
@@ -102,11 +105,13 @@ static int sort_hashlist_by_essidlen(const void *a, const void *b)
 {
 const hashlist_t *ia = (const hashlist_t *)a;
 const hashlist_t *ib = (const hashlist_t *)b;
+int cmp;
 
 if(ia->essidlen > ib->essidlen) return 1;
 else if(ia->essidlen < ib->essidlen) return -1;
-if(memcmp(ia->essid, ib->essid, ia->essidlen) > 0) return 1;
-else if(memcmp(ia->essid, ib->essid, ia->essidlen) < 0) return -1;
+cmp = memcmp(ia->essid, ib->essid, ia->essidlen);
+if(cmp > 0) return 1;
+else if(cmp < 0) return -1;
 return 0;
 }
 
@@ -114,9 +119,11 @@ static int sort_hashlist_by_macap(const void *a, const void *b)
 {
 const hashlist_t *ia = (const hashlist_t *)a;
 const hashlist_t *ib = (const hashlist_t *)b;
+int cmp;
 
-if(memcmp(ia->ap, ib->ap, 6) > 0) return 1;
-else if(memcmp(ia->ap, ib->ap, 6) < 0) return -1;
+cmp = memcmp(ia->ap, ib->ap, 6);
+if(cmp > 0) return 1;
+else if(cmp < 0) return -1;
 return 0;
 }
 
@@ -124,9 +131,11 @@ static int sort_hashlist_by_macclient(const void *a, const void *b)
 {
 const hashlist_t *ia = (const hashlist_t *)a;
 const hashlist_t *ib = (const hashlist_t *)b;
+int cmp;
 
-if(memcmp(ia->client, ib->client, 6) > 0) return 1;
-else if(memcmp(ia->client, ib->client, 6) < 0) return -1;
+cmp = memcmp(ia->client, ib->client, 6);
+if(cmp > 0) return 1;
+else if(cmp < 0) return -1;
 return 0;
 }
 
@@ -156,9 +165,11 @@ static int sort_ouilist_by_oui(const void *a, const void *b)
 {
 const ouilist_t *ia = (const ouilist_t *)a;
 const ouilist_t *ib = (const ouilist_t *)b;
+int cmp;
 
-if(memcmp(ia->oui, ib->oui, 3) > 0) return 1;
-else if(memcmp(ia->oui, ib->oui, 3) < 0) return -1;
+cmp = memcmp(ia->oui, ib->oui, 3);
+if(cmp > 0) return 1;
+else if(cmp < 0) return -1;
 return 0;
 }
 /*===========================================================================*/
@@ -174,11 +185,13 @@ static int sort_essidlistin(const void *a, const void *b)
 {
 const essidlist_t *ia = (const essidlist_t *)a;
 const essidlist_t *ib = (const essidlist_t *)b;
+int cmp;
 
 if(ia->essidlen > ib->essidlen) return 1;
 else if(ia->essidlen < ib->essidlen) return -1;
-if(memcmp(ia->essid, ib->essid, ia->essidlen) > 0) return 1;
-else if(memcmp(ia->essid, ib->essid, ia->essidlen) < 0) return -1;
+cmp = memcmp(ia->essid, ib->essid, ia->essidlen);
+if(cmp > 0) return 1;
+else if(cmp < 0) return -1;
 return 0;
 }
 /*===========================================================================*/
@@ -193,9 +206,11 @@ static int sort_maclistin(const void *a, const void *b)
 {
 const maclist_t *ia = (const maclist_t *)a;
 const maclist_t *ib = (const maclist_t *)b;
+int cmp;
 
-if(memcmp(ia->mac, ib->mac, 6) > 0) return 1;
-else if(memcmp(ia->mac, ib->mac, 6) < 0) return -1;
+cmp = memcmp(ia->mac, ib->mac, 6);
+if(cmp > 0) return 1;
+else if(cmp < 0) return -1;
 return 0;
 }
 /*===========================================================================*/
