@@ -13,6 +13,7 @@
 #include <curl/curl.h>
 
 #include "include/strings.c"
+#include "include/fileops.c"
 
 #define LINEBUFFER_MAX	256
 #define OUIBUFFER_MAX	8192
@@ -64,38 +65,6 @@ fprintf(stdout, "\ndownload finished\n");
 return true;
 }
 /*===========================================================================*/
-static size_t chop(char *buffer,  size_t len)
-{
-static char *ptr;
-
-ptr = buffer +len -1;
-while (len) {
-	if (*ptr != '\n') break;
-	*ptr-- = 0;
-	len--;
-	}
-
-while (len) {
-	if (*ptr != '\r') break;
-	*ptr-- = 0;
-	len--;
-	}
-return len;
-}
-/*---------------------------------------------------------------------------*/
-static int fgetline(FILE *inputstream, size_t size, char *buffer)
-{
-if (feof(inputstream)) return -1;
-		char *buffptr = fgets (buffer, size, inputstream);
-
-	if (buffptr == NULL) return -1;
-
-	size_t len = strlen(buffptr);
-	len = chop(buffptr, len);
-
-return len;
-}
-/*===========================================================================*/
 static void getessidinfo(char *essidname)
 {
 static int l, p;
@@ -122,7 +91,7 @@ for(p = 0; p < l; p++)
 	}
 
 memset(&essidbuffer, 0, 66);
-if(hex2bin(essidname, essidbuffer, l /2) == false)
+if(hex2bin(essidname, essidbuffer, l /2) == -1)
 	{
 	fprintf(stderr, "not a valid ESSID hex string\n");
 	return;
@@ -186,7 +155,7 @@ if((l%2 != 0) || (l > 64))
 	return;
 	}
 memset(&essidbuffer, 0, 66);
-if(hex2bin(essidptr, essidbuffer, l /2) == false)
+if(hex2bin(essidptr, essidbuffer, l /2) == -1)
 	{
 	fprintf(stderr, "wrong ESSID %s\n", essidptr);
 	return;
